==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/style/DropCapFormat.hpp <==
#ifndef _COM_SUN_STAR_STYLE_DROPCAPFORMAT_HPP_
#define _COM_SUN_STAR_STYLE_DROPCAPFORMAT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_STYLE_DROPCAPFORMAT_HDL_
#include "com/sun/star/style/DropCapFormat.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace style {

inline DropCapFormat::DropCapFormat() SAL_THROW( () )
    : Lines(0)
    , Count(0)
    , Distance(0)
{
}

inline DropCapFormat::DropCapFormat(const ::sal_Int8& Lines_, const ::sal_Int8& Count_, const ::sal_Int16& Distance_) SAL_THROW( () )
    : Lines(Lines_)
    , Count(Count_)
    , Distance(Distance_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::style::DropCapFormat const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.style.DropCapFormat");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_STYLE_DROPCAPFORMAT_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/style/DropCapFormat.hpp <==
#ifndef _COM_SUN_STAR_STYLE_DROPCAPFORMAT_HPP_
#define _COM_SUN_STAR_STYLE_DROPCAPFORMAT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_STYLE_DROPCAPFORMAT_HDL_
#include "com/sun/star/style/DropCapFormat.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace style {

inline DropCapFormat::DropCapFormat() SAL_THROW( () )
    : Lines(0)
    , Count(0)
    , Distance(0)
{
}

inline DropCapFormat::DropCapFormat(const ::sal_Int8& Lines_, const ::sal_Int8& Count_, const ::sal_Int16& Distance_) SAL_THROW( () )
    : Lines(Lines_)
    , Count(Count_)
    , Distance(Distance_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace style {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::style::DropCapFormat const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.style.DropCapFormat");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::style::DropCapFormat const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::style::DropCapFormat >::get();
}

#endif // _COM_SUN_STAR_STYLE_DROPCAPFORMAT_HPP_
